@@ -5,6 +5,10 @@ from .utils import split_build_url, first, split_group_project_slug
 squad = Squad()
 
 
+def compare_builds(baseline_id, build_id):
+    return Project.compare_builds(baseline_id, build_id)
+
+
 def retrieve_latest_builds(project_full_name, count=10):
     return squad.builds(count=count, project__full_name=project_full_name)
 
@@ -78,4 +82,4 @@ def submit_results(group_project_slug=None, build_version=None, env_slug=None, t
         metric.result = metrics[metric_name]
         testrun.add_metric(metric)
 
-    testrun.submit_results()
+    return testrun.submit_results()
